﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using DlhSoft.Windows.Data;

namespace GanttChartViewIncreasePerformanceSample
{
    /// <summary>
    /// Interaction logic for Window1.xaml
    /// </summary>
    public partial class Window1 : Window
    {
        public Window1()
        {
            InitializeComponent();

            List<SimpleTaskItem> simpleTaskItems = new List<SimpleTaskItem>
            {
                new SimpleTaskItem { Content = "Task 1" },
                new SimpleTaskItem { Content = "Task 1.1", Indentation = 1, Start = DateTime.Today, Effort = TimeSpan.Parse("08:00:00"), CompletedEffort = TimeSpan.Parse("04:00:00") },
                new SimpleTaskItem { Content = "Task 1.2", Indentation = 1 },
                new SimpleTaskItem { Content = "Task 1.2.1", Indentation = 2, Start = DateTime.Today, Effort = TimeSpan.Parse("08:00:00") },
                new SimpleTaskItem { Content = "Task 1.2.2", Indentation = 2, Start = DateTime.Today, Effort = TimeSpan.Parse("16:00:00") },
                new SimpleTaskItem { Content = "Task 2", IsExpanded = true },
                new SimpleTaskItem { Content = "Task 2.1", Indentation = 1, Start = DateTime.Today, Effort = TimeSpan.Parse("16:00:00"), CompletedEffort = TimeSpan.Parse("16:00:00") },
                new SimpleTaskItem { Content = "Task 2.2", Indentation = 1, Start = DateTime.Today, Effort = TimeSpan.Parse("08:00:00"), CompletedEffort = TimeSpan.Parse("06:00:00") },
                new SimpleTaskItem { Content = "Task 2.3", Indentation = 1, IsExpanded = true },
                new SimpleTaskItem { Content = "Task 2.3.1", Indentation = 2, Start = DateTime.Today, Effort = TimeSpan.Parse("1.16:00:00"), Cost = 2000 },
                new SimpleTaskItem { Content = "Task 2.3.2", Indentation = 2, Start = DateTime.Today, Effort = TimeSpan.Parse("08:00:00") },
                new SimpleTaskItem { Content = "Task 3", Start = DateTime.Today, Effort = TimeSpan.Parse("12:30:00"), CompletedEffort = TimeSpan.Parse("02:30:00") },
                new SimpleTaskItem { Content = "Task 4", Start = DateTime.Today, Effort = TimeSpan.Parse("16:00:00") },
                new SimpleTaskItem { Content = "Task 5", Start = DateTime.Today, Effort = TimeSpan.Parse("20:00:00") },
                new SimpleTaskItem { Content = "Task 6", Start = DateTime.Today, Effort = TimeSpan.Zero }
            };

            simpleTaskItems[8].Predecessors = new List<SimplePredecessorItem> { new SimplePredecessorItem { TaskItem = simpleTaskItems[7] } };
            simpleTaskItems[10].Predecessors = new List<SimplePredecessorItem> { new SimplePredecessorItem { TaskItem = simpleTaskItems[9] } };
            simpleTaskItems[11].Predecessors = new List<SimplePredecessorItem> { new SimplePredecessorItem { TaskItem = simpleTaskItems[8] }, new SimplePredecessorItem { TaskItem = simpleTaskItems[10], DependencyType = DependencyType.StartStart, Lag = TimeSpan.Parse("12:00:00") } };
            simpleTaskItems[14].Predecessors = new List<SimplePredecessorItem> { new SimplePredecessorItem { TaskItem = simpleTaskItems[13], Lag = TimeSpan.Parse("02:00:00") } };

            List<SimpleResourceItem> assignableSimpleResourceItems = new List<SimpleResourceItem>
            {
                new SimpleResourceItem { Content = "Resource 1", CostPerUsage = 100, CostPerHour = 10 },
                new SimpleResourceItem { Content = "Resource 2", CostPerHour = 20 }
            };

            for (int i = 3; i <= 16; i++)
                assignableSimpleResourceItems.Add(new SimpleResourceItem { Content = "Resource " + i });

            simpleTaskItems[12].Assignments = new List<SimpleAssignmentItem> { new SimpleAssignmentItem { ResourceItem = assignableSimpleResourceItems[0] } };
            simpleTaskItems[13].Assignments = new List<SimpleAssignmentItem> { new SimpleAssignmentItem { ResourceItem = assignableSimpleResourceItems[0] }, new SimpleAssignmentItem { ResourceItem = assignableSimpleResourceItems[1], AllocationUnits = 0.5 } };

            // The data collection is large.
            for (int i = 7; i <= 1024; i++)
                simpleTaskItems.Add(new SimpleTaskItem { Content = "Task " + i, Start = DateTime.Today, Effort = TimeSpan.Parse("08:00:00") });

            // In order to optimize data loading and avoid data binding use the simple data management mode by using SimpleTaskItem and SimpleResourceItem objects within TaskManager and ResourceManager.
            // You can and access, update, add, and remove tasks and resources by calling the appropriate methods, such as the indexer, and Add, AddRange, Insert, InsertRange, RemoveAt, RemoveRangeAt, Remove, RemoveRange, and Clear, from TaskManager and ResourceManager.
            // Note that when you use simple data management mode the TaskManager and ResourceManager don't automatically update values back to the original simple items. You can access updated values using the managed Task and Resource objects accessible through the indexers of TaskManager and ResourceManager.
            ResourceManager assignableResourceManager = new ResourceManager(assignableSimpleResourceItems);
            TaskManager taskManager = new TaskManager(simpleTaskItems, assignableResourceManager, Schedule.Standard);

            // Asynchronous presentation is enabled in markup.
            GanttChartView.TaskManagerSource = taskManager;
        }
    }
}
